@@ -114,13 +114,11 @@ QStringList AppPackageKitResource::mimetypes() const
 
 static constexpr auto s_addonKinds = {AppStream::Component::KindAddon, AppStream::Component::KindCodec};
 
-QStringList AppPackageKitResource::categories()
+bool AppPackageKitResource::hasCategory(const QString &category) const
 {
-    auto cats = m_appdata.categories();
-    if (!kContainsValue(s_addonKinds, m_appdata.kind())) {
-        cats.append(QStringLiteral("Application"));
-    }
-    return cats;
+    if (m_appdata.kind() != AppStream::Component::KindAddon && category == QStringLiteral("Application"))
+        return true;
+    return m_appdata.hasCategory(category);
 }
 
 QString AppPackageKitResource::comment()
@@ -260,8 +258,8 @@ QString AppPackageKitResource::versionString()
 
 QDate AppPackageKitResource::releaseDate() const
 {
-    if (!m_appdata.releasesPlain().isEmpty()) {
-        const auto release = m_appdata.releasesPlain().indexSafe(0).value();
+    if (const auto releases = m_appdata.releasesPlain(); !releases.isEmpty()) {
+        auto release = releases.indexSafe(0).value();
         return release.timestamp().date();
     }
 
